import React from "react";
import M from "materialize-css";
import { Meteor } from "meteor/meteor";
import { i18n } from "meteor/universe:i18n";
import ConfirmButton from "../dialogs/ConfirmButton";

/**
 * delete button used in datatable view
 *
 * @param deleteMethod
 * @param deleteId
 * @param question
 * @param successMessage
 */
export const DeleteButton = ({
  deleteMethod,
  deleteId,
  question,
  successMessage,
  deleteHeader = "Delete Record",
  deleteLabel = "Delete",
  deleteError = 'Delete Error'
}) => {
  return (
    <ConfirmButton
      header={i18n.__('messages.delete_title')}
      question={question}
      label={
        <i className="fa fa-trash-o fa-2x" title={i18n.__('messages.delete')}>
          {" "}
        </i>
      }
      buttonClassName={"delete-button"}
      actionYes={() => {
        M.Toast.dismissAll();
        Meteor.call(deleteMethod, deleteId, (error, result) => {
          if (error) {
            const message =
              error.error || error.mesage || i18n.__("messages.delete_error");
            M.toast({
              html: message,
              classes: "text-danger",
            });
          } else {
            M.toast({
              html: successMessage,
              classes: "text-success",
            });
          }
        });
      }}
    />
  );

  //component materialize <Modal> not working in android !!!!!!
};

export default DeleteButton;
