import React, {useState, useEffect, useRef} from 'react';
import {TextInput, Row} from 'react-materialize';
import {i18n} from 'meteor/universe:i18n';

const WAIT_INTERVAL = 500; //interval research data view
const ENTER_KEY = 13;

const Search = ({
                    search: fulltext,
                    onSearch: setFulltext,
                    label = i18n.__('messages.search') + ' ...'
                }) => {

    const [temp, setTemp] = useState(fulltext);

    useEffect(() => {
        setTemp(fulltext);
    }, [fulltext])

    const ref = useRef(null);
    const onEnter = () => {
        if (ref.current) {
            Meteor.clearTimeout(ref.current);
            ref.current = null;
        }
        setFulltext(temp);
    };
    const onInputChange = (value) => {
        const _value = value || '';
        setTemp(_value)
        if (ref.current) {
            Meteor.clearTimeout(ref.current);
            ref.current = null;
        }
        ref.current = Meteor.setTimeout(() => {
            setFulltext(_value);
        }, WAIT_INTERVAL);
    };

    return (
        <Row>
            <TextInput
                s={12}
                label={label}
                value={temp || ''}
                onChange={e => onInputChange(e.target.value)}
                onKeyDown={e => {
                    if (e.keyCode === ENTER_KEY) {
                        onEnter();
                    }
                }}
            />
        </Row>);
}

export default Search;