import buildQueryFulltext from "../../utils/buildQueryFulltext";

export const publishDataTable = (
    check, //from import {check} from "meteor/check";
    selector, fulltext, fulltextFields,
    sortField, sortOrder,
    page, pageSize, fields,
    self, collection,
    collectionName, subsName,
    callback = null
) => {

    check(selector || {}, Object);
    check(sortField, String);
    check(sortOrder, Number);
    check(fulltext || '', String);
    check(fulltextFields, Array);
    check(page || 0, Number);
    check(pageSize || 0, Number);
    if (!page || page < 0) {
        page = 0;
    }
    if (!pageSize || pageSize < 1) {
        pageSize = 10;
    }
    const query = buildQueryFulltext(selector || {}, fulltext, fulltextFields);
    const sort = sortField && (sortOrder === 1 || sortOrder === -1)
        ? {[sortField]: sortOrder}
        : {};

    const options = {sort, limit: pageSize, skip: page * pageSize};
    if (fields){
        check(fields, Object);
        for (const [key, value] of Object.entries(fields)) {
            if (value !== 1 && value !== -1){
                //throw new Meteor.Error(`error publishDataTale subs: ${subsName} - wrong filter ${key}: ${value}`)
                console.error(`error publishDataTale subs: ${subsName} - wrong filter ${key}: ${value}`);
                return [];
            }
        }
        options.fields = fields;
    }

    const transformDoc = (doc) => {
        if (callback) {
            return callback(doc);
        }
        return doc;
    }
    const collectionIdsName = 'DataTablePageIds';
    let init = true;
    let ids = null;
    const handle = collection.find(query, options).observe({
        added(doc) {
            self.added(collectionName, doc._id, transformDoc(doc));
            if (ids) {
                ids.ids.push(doc._id);
                self.changed(collectionIdsName, subsName, ids);
            } else {
                ids = {
                    ids: [doc._id]
                }
                self.added(collectionIdsName, subsName, ids);
            }
        },
        changed(doc) {
            if (init) return;
            self.changed(collectionName, doc._id, transformDoc(doc));
            if (ids) {
                if (ids.ids.indexOf(doc._id) < 0) {
                    ids.ids.push(doc._id);
                    self.changed(collectionIdsName, subsName, ids);
                }
            } else {
                ids = {
                    ids: [doc._id]
                }
                self.added(collectionIdsName, subsName, ids);
            }
        },
        removed(doc) {
            self.removed(collectionName, doc._id);
            if (ids) {
                ids.ids = ids.ids.filter(x => x !== doc._id);
                self.changed(collectionIdsName, subsName, ids);
            }
        }
    });
    self.ready();
    init = false;
    self.onStop(() => handle.stop());
}

export const buildPublishCounter = (
    check, //from import {check} from "meteor/check";
    selfPublish, collection,
    selector, fulltext,
    fulltextFields, counterId
) => {
    check(selector, Object);
    check(fulltext || '', String);
    check(fulltextFields, Array);
    check(counterId, String);
    let count = 0;
    let initializing = true;
    let collection_name = 'DataTableCounter';
    let query = buildQueryFulltext(selector, fulltext, fulltextFields);
    const handle = collection.find(query).observeChanges({
        added: (id) => {
            count += 1;
            if (!initializing) {
                selfPublish.changed(collection_name, counterId, {count});
            }
        },
        removed: (id) => {
            count -= 1;
            selfPublish.changed(collection_name, counterId, {count});
        }
    });
    initializing = false;
    selfPublish.added(collection_name, counterId, {count});
    selfPublish.ready();
    selfPublish.onStop(() => handle.stop());
}

