export const removeDiacritics = (s) => {
    var diacritics = [
        [/\[/, '\\['],
        [/\]/, '\\]'],
        [/\{/, '\\{'],
        [/\}/, '\\}'],
        [/\(/, '\\('],
        [/\)/, '\\)'],
        [/\-/, '\\-'],
        [/\$/, '\\$'],
        [/\^/, '\\^'],
        [/\*/, '\\*'],
        [/\./, '\\.'],

        [/[aàáâãäå]/g, 'a'],
        [/[AÀÁÂÃÄÅ]/g, 'A'],
        [/[cč]/g, 'c'],
        [/[CČ]/g, 'C'],
        [/[dď]/g, 'd'],
        [/[DĎ]/g, 'Ď'],
        [/[eéěë]/g, 'e'],
        [/[EÉĚË]/g, 'E'],
        [/[ií]/g, 'i'],
        [/[IÍ]/g, 'I'],
        [/[lľĺ]/g, 'l'],
        [/[LĽĽ]/g, 'L'],
        [/[nň]/g, 'n'],
        [/[NŇ]/g, 'N'],
        [/[oóôö]/g, 'o'],
        [/[OÓÔÖ]/g, 'O'],
        [/[rřŕ]/g, 'r'],
        [/[RŘŔ]/g, 'R'],
        [/[sš]/g, 's'],
        [/[SŠ]/g, 'S'],
        [/[tť]/g, 't'],
        [/[TŤ]/g, 'T'],
        [/[uůûü]/g, 'u'],
        [/[UÚŮÛÜ]/g, 'U'],
        [/[yýÿý]/g, 'y'],
        [/[YÝŸ]/g, 'Y'],
        [/[zž]/g, 'z'],
        [/[ZŽ]/g, 'Z']
    ];
    for (var i = 0; i < diacritics.length; i++) {
        s = s.replace(diacritics[i][0], diacritics[i][1]);
    }
    return s;
};

/** query for futtext regex */
const replaceDiacritics = (s) => {
    const diacritics = [
        [/\[/, '\\['],
        [/\]/, '\\]'],
        [/\{/, '\\{'],
        [/\}/, '\\}'],
        [/\(/, '\\('],
        [/\)/, '\\)'],
        [/\-/, '\\-'],
        [/\$/, '\\$'],
        [/\^/, '\\^'],
        [/\*/, '\\*'],
        [/\./, '\\.'],

        [/[aAÀÁÂÃÄÅàáâãäå]/ig, '[aAÀÁÂÃÄÅàáâãäå]'],
        [/[cCčČ]/ig, '[cCčČ]'],
        [/[dDďĎ]/ig, '[dDďĎ]'],
        [/[eEéEěĚëË]/ig, '[eEéEěĚëË]'],
        [/[iIíÍ]/ig, '[iIíÍ]'],
        [/[lLľĽĺĽ]/ig, '[lLľĽĺĽ]'],
        [/[nNňŇ]/ig, '[nNňŇ]'],
        [/[oOóÓôÔÖö]/ig, '[oOóÓôÔÖö]'],
        [/[rRřŘŕŔ]/ig, '[rRřŘŕŔ]'],
        [/[sSŠš]/ig, '[sSŠš]'],
        [/[tTťŤ]/ig, '[tTťŤ]'],
        [/[uUúÚůŮûÛüÜ]/ig, '[uUúÚůŮûÛüÜ]'],
        [/[yYýÝŸÿý]/ig, '[yYŸÿý]'],
        [/[zZŽž]/ig, '[zZŽž]']
    ];
    for (let i = 0; i < diacritics.length; i++) {
        s = s.replace(diacritics[i][0], diacritics[i][1]);
    }
    return s;
};

const buildQueryFulltext = (selector, fulltext, fields) => {
    if (!fulltext) {
        return selector;
    }
    let regex = new RegExp(replaceDiacritics(fulltext), 'i');
    let or = {$or: []};
    for (let field of fields) {
        let cond = {};
        cond[field] = regex;
        or.$or.push(cond);
    }
    let x = {...selector, ...or};
    return x;
};

export default buildQueryFulltext;

