import SimpleSchema from "simpl-schema";
import {i18n} from 'meteor/universe:i18n';

export const createSimpleSchema = (options: any) : SimpleSchema => {
    let s = new SimpleSchema(options, {
        clean: {
            filter: true,
            autoConvert: true,
            removeEmptyStrings: true,
            trimStrings: true,
            getAutoValues: true,
            removeNullsFromArrays: true,
        },
        requiredByDefault: true
    });
    s.messageBox.messageList = {
        "en": {
            'required': i18n.__('simpleSchema.required'),
            'minString': i18n.__('simpleSchema.minString'),
            'maxString': i18n.__('simpleSchema.maxString'),
            'minNumber': i18n.__('simpleSchema.minNumber'),
            'maxNumber': i18n.__('simpleSchema.maxNumber'),
            'minNumberExclusive': i18n.__('simpleSchema.minNumberExclusive'),
            'maxNumberExclusive': i18n.__('simpleSchema.maxNumberExclusive'),
            'minDate': i18n.__('simpleSchema.minDate'),
            'maxDate': i18n.__('simpleSchema.maxDate'),
            'badDate': i18n.__('simpleSchema.badDate'),
            'minCount': i18n.__('simpleSchema.minCount'),
            'maxCount': i18n.__('simpleSchema.maxCount'),
            'noDecimal': i18n.__('simpleSchema.noDecimal'),
            'notAllowed': i18n.__('simpleSchema.notAllowed'),
            'expectedType': i18n.__('simpleSchema.expectedType'),
            'expectedString': i18n.__('simpleSchema.expectedString'),
            'expectedNumber': i18n.__('simpleSchema.expectedNumber'),
            'expectedBoolean': i18n.__('simpleSchema.expectedBoolean'),
            'expectedArray': i18n.__('simpleSchema.expectedArray'),
            'expectedObject': i18n.__('simpleSchema.expectedObject'),
            'expectedConstructor': i18n.__('simpleSchema.expectedConstructor'),
            'keyNotInSchema': i18n.__('simpleSchema.keyNotInSchema'),
            "idNotFound": i18n.__('simpleSchema.idNotFound'),
            "wrongUnit": i18n.__('simpleSchema.wrongUnit'),
            "wrongRola": i18n.__('simpleSchema.wrongRola'),
            "wrongConfirmPassw": i18n.__('simpleSchema.wrongConfirmPassw'),
            'regEx': [
                {'msg': i18n.__('simpleSchema.regEx.msg')},
                {'exp': 'simpleSchema.RegEx.Email', 'msg': i18n.__('simpleSchema.regEx.email')},
                {'exp': 'simpleSchema.RegEx.WeakEmail', 'msg': i18n.__('simpleSchema.regEx.weakEmail')},
                {'exp': 'simpleSchema.RegEx.Domain', 'msg': i18n.__('simpleSchema.regEx.domain')},
                {'exp': 'simpleSchema.RegEx.WeakDomain', 'msg': i18n.__('simpleSchema.regEx.weakDomain')},
                {'exp': 'simpleSchema.RegEx.IP', 'msg': i18n.__('simpleSchema.regEx.ip')},
                {'exp': 'simpleSchema.RegEx.IPv4', 'msg': i18n.__('simpleSchema.regEx.ipV4')},
                {'exp': 'simpleSchema.RegEx.IPv6', 'msg': i18n.__('simpleSchema.regEx.ipV6')},
                {'exp': 'simpleSchema.RegEx.Url', 'msg': i18n.__('simpleSchema.regEx.url')},
                {'exp': 'simpleSchema.RegEx.Id', 'msg': i18n.__('simpleSchema.regEx.id')}
            ]
        }
    };

    return s;
}